Index: test/mjsunit/strict-mode.js |
diff --git a/test/mjsunit/strict-mode.js b/test/mjsunit/strict-mode.js |
index fcfe264e988471becfb6804ff10037d5201ea2ff..e9e1ddd9cf25c6901a63d910dd6c27dbb6329d56 100644 |
--- a/test/mjsunit/strict-mode.js |
+++ b/test/mjsunit/strict-mode.js |
@@ -319,14 +319,8 @@ CheckStrictMode("var variable; delete variable;", SyntaxError); |
+arguments, -arguments, ~arguments, !arguments]; |
})(); |
-// 7.6.1.2 Future Reserved Words |
-var future_reserved_words = [ |
- "class", |
- "enum", |
- "export", |
- "extends", |
- "import", |
- "super", |
+// 7.6.1.2 Future Reserved Words in strict mode |
+var future_strict_reserved_words = [ |
"implements", |
"interface", |
"let", |
@@ -337,9 +331,10 @@ var future_reserved_words = [ |
"static", |
"yield" ]; |
-function testFutureReservedWord(word) { |
+function testFutureStrictReservedWord(word) { |
// Simple use of each reserved word |
CheckStrictMode("var " + word + " = 1;", SyntaxError); |
+ CheckStrictMode("typeof (" + word + ");", SyntaxError); |
// object literal properties |
eval("var x = { " + word + " : 42 };"); |
@@ -383,8 +378,8 @@ function testFutureReservedWord(word) { |
SyntaxError); |
} |
-for (var i = 0; i < future_reserved_words.length; i++) { |
- testFutureReservedWord(future_reserved_words[i]); |
+for (var i = 0; i < future_strict_reserved_words.length; i++) { |
+ testFutureStrictReservedWord(future_strict_reserved_words[i]); |
} |
function testAssignToUndefined(test, should_throw) { |